########################################################
# Analysis.R
########################################################

# 28 March 2021

# This R script loads the data file data_processed.csv and outputs the data file corr_individual.csv and core analyses that are reported in the journal article 

library(tidyverse)
library(Hmisc)
library(moments)
library(psych)

# Import data
# setwd("~/Desktop/misinformation")
data <- read_csv("data_preprocessed.csv", guess_max = 2000)

# ----------------------------------------------
# Hillary vs Trump analysis (use ClintonTrump variable)

data_acc_mturk_clinton <- data %>% 
  filter(Condition == 1) %>% 
  filter(Study == 1) %>% 
  filter(ClintonTrump == 1)

data_acc_mturk_trump <- data %>% 
  filter(Condition == 1) %>% 
  filter(Study == 1) %>% 
  filter(ClintonTrump == 2)

data_acc_lucid_clinton <- data %>% 
  filter(Condition == 1) %>% 
  filter(Study == 2) %>% 
  filter(ClintonTrump == 1)

data_acc_lucid_trump <- data %>% 
  filter(Condition == 1) %>% 
  filter(Study == 2) %>% 
  filter(ClintonTrump == 2)

data_share_mturk_clinton <- data %>% 
  filter(Condition == 2) %>% 
  filter(Study == 1) %>% 
  filter(ClintonTrump == 1) %>%
  filter(Media_Share == 1)

data_share_mturk_trump <- data %>% 
  filter(Condition == 2) %>% 
  filter(Study == 1) %>% 
  filter(ClintonTrump == 2) %>%
  filter(Media_Share == 1)

data_share_lucid_clinton <- data %>% 
  filter(Condition == 2) %>% 
  filter(Study == 2) %>% 
  filter(ClintonTrump == 1) %>%
  filter(Media_Share == 1)

data_share_lucid_trump <- data %>% 
  filter(Condition == 2) %>% 
  filter(Study == 2) %>% 
  filter(ClintonTrump == 2) %>%
  filter(Media_Share == 1)

# Accuracy analysis - Table 1

Hmisc::rcorr(as.matrix(data_acc_mturk_clinton[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_mturk_trump[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_lucid_clinton[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_lucid_trump[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))

# Accuracy discernment analysis - Table 2

Hmisc::rcorr(as.matrix(data_acc_mturk_clinton[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_mturk_trump[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_lucid_clinton[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_lucid_trump[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))

# Sharing analysis - Table 3

Hmisc::rcorr(as.matrix(data_share_mturk_clinton[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))
Hmisc::rcorr(as.matrix(data_share_mturk_trump[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))
Hmisc::rcorr(as.matrix(data_share_lucid_clinton[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))
Hmisc::rcorr(as.matrix(data_share_lucid_trump[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))

# Sharing discernment analysis - Table 4

Hmisc::rcorr(as.matrix(data_share_mturk_clinton[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_share_mturk_trump[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_share_lucid_clinton[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_share_lucid_trump[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))

# ------------------------------------------------------
# Democrat vs Republican (forced choice) analysis 

data_acc_mturk_dem <- data %>% 
  filter(Condition == 1) %>% 
  filter(Study == 1) %>% 
  filter(DemRep == 1)

data_acc_mturk_rep <- data %>% 
  filter(Condition == 1) %>% 
  filter(Study == 1) %>% 
  filter(DemRep == 2)

data_acc_lucid_dem <- data %>% 
  filter(Condition == 1) %>% 
  filter(Study == 2) %>% 
  filter(DemRep == 1)

data_acc_lucid_rep <- data %>% 
  filter(Condition == 1) %>% 
  filter(Study == 2) %>% 
  filter(DemRep == 2)

data_share_mturk_dem <- data %>% 
  filter(Condition == 2) %>% 
  filter(Study == 1) %>% 
  filter(DemRep == 1) %>%
  filter(Media_Share == 1)

data_share_mturk_rep <- data %>% 
  filter(Condition == 2) %>% 
  filter(Study == 1) %>% 
  filter(DemRep == 2) %>%
  filter(Media_Share == 1)

data_share_lucid_dem <- data %>% 
  filter(Condition == 2) %>% 
  filter(Study == 2) %>% 
  filter(DemRep == 1) %>%
  filter(Media_Share == 1)

data_share_lucid_rep <- data %>% 
  filter(Condition == 2) %>% 
  filter(Study == 2) %>% 
  filter(DemRep == 2) %>%
  filter(Media_Share == 1)

# Accuracy analysis - Table S3

Hmisc::rcorr(as.matrix(data_acc_mturk_dem[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_mturk_rep[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_lucid_dem[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_lucid_rep[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))

# Accuracy discernment analysis - Table S4

Hmisc::rcorr(as.matrix(data_acc_mturk_dem[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_mturk_rep[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_lucid_dem[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_lucid_rep[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))

# Sharing analysis - Table S5

Hmisc::rcorr(as.matrix(data_share_mturk_dem[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))
Hmisc::rcorr(as.matrix(data_share_mturk_rep[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))
Hmisc::rcorr(as.matrix(data_share_lucid_dem[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))
Hmisc::rcorr(as.matrix(data_share_lucid_rep[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))

# Sharing discernment analysis - Table S6

Hmisc::rcorr(as.matrix(data_share_mturk_dem[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_share_mturk_rep[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_share_lucid_dem[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_share_lucid_rep[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))

# ------------------------------------------------------
# Democrat vs Republican self-identification analysis (removes "Independent" and "other")

data_acc_mturk_dem_ident <- data %>% 
  filter(Condition == 1) %>% 
  filter(Study == 1) %>% 
  filter(Party == 1)

data_acc_mturk_rep_ident <- data %>% 
  filter(Condition == 1) %>% 
  filter(Study == 1) %>% 
  filter(Party == 2)

data_acc_lucid_dem_ident <- data %>% 
  filter(Condition == 1) %>% 
  filter(Study == 2) %>% 
  filter(Party == 1)

data_acc_lucid_rep_ident <- data %>% 
  filter(Condition == 1) %>% 
  filter(Study == 2) %>% 
  filter(Party == 2)

data_share_mturk_dem_ident <- data %>% 
  filter(Condition == 2) %>% 
  filter(Study == 1) %>% 
  filter(Party == 1) %>%
  filter(Media_Share == 1)

data_share_mturk_rep_ident <- data %>% 
  filter(Condition == 2) %>% 
  filter(Study == 1) %>% 
  filter(Party == 2) %>%
  filter(Media_Share == 1)

data_share_lucid_dem_ident <- data %>% 
  filter(Condition == 2) %>% 
  filter(Study == 2) %>% 
  filter(Party == 1) %>%
  filter(Media_Share == 1)

data_share_lucid_rep_ident <- data %>% 
  filter(Condition == 2) %>% 
  filter(Study == 2) %>% 
  filter(Party == 2) %>%
  filter(Media_Share == 1)

# Accuracy analysis - Table S9

Hmisc::rcorr(as.matrix(data_acc_mturk_dem_ident[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_mturk_rep_ident[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_lucid_dem_ident[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_lucid_rep_ident[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))

# Accuracy discernment analysis - Table S10

Hmisc::rcorr(as.matrix(data_acc_mturk_dem_ident[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_mturk_rep_ident[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_lucid_dem_ident[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_lucid_rep_ident[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))

# Sharing analysis - Table S11

Hmisc::rcorr(as.matrix(data_share_mturk_dem_ident[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))
Hmisc::rcorr(as.matrix(data_share_mturk_rep_ident[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))
Hmisc::rcorr(as.matrix(data_share_lucid_dem_ident[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))
Hmisc::rcorr(as.matrix(data_share_lucid_rep_ident[, c("CRT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))

# Sharing discernment analysis - Table S12

Hmisc::rcorr(as.matrix(data_share_mturk_dem_ident[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_share_mturk_rep_ident[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_share_lucid_dem_ident[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_share_lucid_rep_ident[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))

# ----------------------------------------------
# Democrat vs Republican (forced choice) strong partisan analysis

data_acc_mturk_par <- data %>% 
  filter(Condition == 1) %>% 
  filter(Study == 1) %>% 
  filter(Partisan == 1)

data_acc_lucid_par <- data %>% 
  filter(Condition == 1) %>% 
  filter(Study == 2) %>% 
  filter(Partisan == 1)

data_share_mturk_par <- data %>% 
  filter(Condition == 2) %>% 
  filter(Study == 1) %>% 
  filter(Media_Share == 1) %>% 
  filter(Partisan == 1)

data_share_lucid_par <- data %>% 
  filter(Condition == 2) %>% 
  filter(Study == 2) %>% 
  filter(Media_Share == 1) %>% 
  filter(Partisan == 1)

# Accuracy analysis - Table S13

Hmisc::rcorr(as.matrix(data_acc_mturk_par[, c("CRT_Sum", "Fake_PC", "Hyp_PC", "Main_PC", "Fake_nPC", "Hyp_nPC", "Main_nPC")]))
Hmisc::rcorr(as.matrix(data_acc_lucid_par[, c("CRT_Sum", "Fake_PC", "Hyp_PC", "Main_PC", "Fake_nPC", "Hyp_nPC", "Main_nPC")]))

# Accuracy discernment analysis - Table S14

Hmisc::rcorr(as.matrix(data_acc_mturk_par[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_lucid_par[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))

# Sharing analysis - Table S15

Hmisc::rcorr(as.matrix(data_share_mturk_par[, c("CRT_Sum", "Fake_PC", "Hyp_PC", "Main_PC", "Fake_nPC", "Hyp_nPC", "Main_nPC")]))
Hmisc::rcorr(as.matrix(data_share_lucid_par[, c("CRT_Sum", "Fake_PC", "Hyp_PC", "Main_PC", "Fake_nPC", "Hyp_nPC", "Main_nPC")]))

# Sharing discernment analysis - table S16

Hmisc::rcorr(as.matrix(data_share_mturk_par[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_share_lucid_par[, c("CRT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))

#------------------------------------------
# Berlin numeracy test analysis

# Accuracy analysis - Table S18

Hmisc::rcorr(as.matrix(data_acc_lucid_dem[, c("BNT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_lucid_rep[, c("BNT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))

# Accuracy discernment analysis - Table S19

Hmisc::rcorr(as.matrix(data_acc_lucid_dem[, c("BNT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_acc_lucid_rep[, c("BNT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))

# Sharing analysis - Table S20

Hmisc::rcorr(as.matrix(data_share_lucid_dem[, c("BNT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))
Hmisc::rcorr(as.matrix(data_share_lucid_rep[, c("BNT_Sum", "Fake_Dem", "Hyp_Dem", "Main_Dem", "Fake_Rep", "Hyp_Rep", "Main_Rep")]))

# Sharing discernment analysis - Table S21

Hmisc::rcorr(as.matrix(data_share_lucid_dem[, c("BNT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))
Hmisc::rcorr(as.matrix(data_share_lucid_rep[, c("BNT_Sum", "ZDis_Main_Minus_Fake_Dem", "ZDis_Main_Minus_Hyp_Dem", "ZDis_Hyp_Minus_Fake_Dem", "ZDis_Main_Minus_Fake_Rep", "ZDis_Main_Minus_Hyp_Rep", "ZDis_Hyp_Minus_Fake_Rep")]))

# ------------------------------------------------------
# Democrat vs Republican individual-level correlation analysis

corr_acc_mturk_dem <- data_acc_mturk_dem %>%
  select(CRT_Sum, Dem_Fake1, Dem_Fake2, Dem_Fake3, Dem_Fake4, Dem_Fake5, Rep_Fake1, Rep_Fake2, Rep_Fake3, Rep_Fake4, Rep_Fake5, Dem_Hyp1, Dem_Hyp2, Dem_Hyp3, Dem_Hyp4, Dem_Hyp5, Rep_Hyp1, Rep_Hyp2, Rep_Hyp3, Rep_Hyp4, Rep_Hyp5, Dem_Main1, Dem_Main2, Dem_Main3, Dem_Main4, Dem_Main5, Rep_Main1, Rep_Main2, Rep_Main3, Rep_Main4, Rep_Main5) %>% 
  corr.test(adjust = "none", minlength = 30) %>% 
  print(short = FALSE, digits = 5)
corr_acc_mturk_dem <- corr_acc_mturk_dem %>%
  rownames_to_column(var = "row_name")
corr_acc_mturk_dem <- corr_acc_mturk_dem %>%
  add_column(study = "mTurk_Democrat_Accuracy")

corr_acc_mturk_rep <- data_acc_mturk_rep %>%
  select(CRT_Sum, Dem_Fake1, Dem_Fake2, Dem_Fake3, Dem_Fake4, Dem_Fake5, Rep_Fake1, Rep_Fake2, Rep_Fake3, Rep_Fake4, Rep_Fake5, Dem_Hyp1, Dem_Hyp2, Dem_Hyp3, Dem_Hyp4, Dem_Hyp5, Rep_Hyp1, Rep_Hyp2, Rep_Hyp3, Rep_Hyp4, Rep_Hyp5, Dem_Main1, Dem_Main2, Dem_Main3, Dem_Main4, Dem_Main5, Rep_Main1, Rep_Main2, Rep_Main3, Rep_Main4, Rep_Main5) %>% 
  corr.test(adjust = "none", minlength = 30) %>% 
  print(short = FALSE, digits = 5)
corr_acc_mturk_rep <- corr_acc_mturk_rep %>%
  rownames_to_column(var = "row_name")
corr_acc_mturk_rep <- corr_acc_mturk_rep %>%
  add_column(study = "mTurk_Republican_Accuracy")

corr_acc_lucid_dem <- data_acc_lucid_dem %>%
  select(CRT_Sum, Dem_Fake1, Dem_Fake2, Dem_Fake3, Dem_Fake4, Dem_Fake5, Rep_Fake1, Rep_Fake2, Rep_Fake3, Rep_Fake4, Rep_Fake5, Dem_Hyp1, Dem_Hyp2, Dem_Hyp3, Dem_Hyp4, Dem_Hyp5, Rep_Hyp1, Rep_Hyp2, Rep_Hyp3, Rep_Hyp4, Rep_Hyp5, Dem_Main1, Dem_Main2, Dem_Main3, Dem_Main4, Dem_Main5, Rep_Main1, Rep_Main2, Rep_Main3, Rep_Main4, Rep_Main5) %>% 
  corr.test(adjust = "none", minlength = 30) %>% 
  print(short = FALSE, digits = 5)
corr_acc_lucid_dem <- corr_acc_lucid_dem %>%
  rownames_to_column(var = "row_name")
corr_acc_lucid_dem <- corr_acc_lucid_dem %>%
  add_column(study = "Lucid_Democrat_Accuracy")

corr_acc_lucid_rep <- data_acc_lucid_rep %>%
  select(CRT_Sum, Dem_Fake1, Dem_Fake2, Dem_Fake3, Dem_Fake4, Dem_Fake5, Rep_Fake1, Rep_Fake2, Rep_Fake3, Rep_Fake4, Rep_Fake5, Dem_Hyp1, Dem_Hyp2, Dem_Hyp3, Dem_Hyp4, Dem_Hyp5, Rep_Hyp1, Rep_Hyp2, Rep_Hyp3, Rep_Hyp4, Rep_Hyp5, Dem_Main1, Dem_Main2, Dem_Main3, Dem_Main4, Dem_Main5, Rep_Main1, Rep_Main2, Rep_Main3, Rep_Main4, Rep_Main5) %>% 
  corr.test(adjust = "none", minlength = 30) %>% 
  print(short = FALSE, digits = 5)
corr_acc_lucid_rep <- corr_acc_lucid_rep %>%
  rownames_to_column(var = "row_name")
corr_acc_lucid_rep <- corr_acc_lucid_rep %>%
  add_column(study = "Lucid_Republican_Accuracy")

corr_share_mturk_dem <- data_share_mturk_dem %>%
  select(CRT_Sum, Dem_Fake1, Dem_Fake2, Dem_Fake3, Dem_Fake4, Dem_Fake5, Rep_Fake1, Rep_Fake2, Rep_Fake3, Rep_Fake4, Rep_Fake5, Dem_Hyp1, Dem_Hyp2, Dem_Hyp3, Dem_Hyp4, Dem_Hyp5, Rep_Hyp1, Rep_Hyp2, Rep_Hyp3, Rep_Hyp4, Rep_Hyp5, Dem_Main1, Dem_Main2, Dem_Main3, Dem_Main4, Dem_Main5, Rep_Main1, Rep_Main2, Rep_Main3, Rep_Main4, Rep_Main5) %>% 
  corr.test(adjust = "none", minlength = 30) %>% 
  print(short = FALSE, digits = 5)
corr_share_mturk_dem <- corr_share_mturk_dem %>%
  rownames_to_column(var = "row_name")
corr_share_mturk_dem <- corr_share_mturk_dem %>%
  add_column(study = "mTurk_Democrat_Sharing")

corr_share_mturk_rep <- data_share_mturk_rep %>%
  select(CRT_Sum, Dem_Fake1, Dem_Fake2, Dem_Fake3, Dem_Fake4, Dem_Fake5, Rep_Fake1, Rep_Fake2, Rep_Fake3, Rep_Fake4, Rep_Fake5, Dem_Hyp1, Dem_Hyp2, Dem_Hyp3, Dem_Hyp4, Dem_Hyp5, Rep_Hyp1, Rep_Hyp2, Rep_Hyp3, Rep_Hyp4, Rep_Hyp5, Dem_Main1, Dem_Main2, Dem_Main3, Dem_Main4, Dem_Main5, Rep_Main1, Rep_Main2, Rep_Main3, Rep_Main4, Rep_Main5) %>% 
  corr.test(adjust = "none", minlength = 30) %>% 
  print(short = FALSE, digits = 5)
corr_share_mturk_rep <- corr_share_mturk_rep %>%
  rownames_to_column(var = "row_name")
corr_share_mturk_rep <- corr_share_mturk_rep %>%
  add_column(study = "mTurk_Republican_Sharing")

corr_share_lucid_dem <- data_share_lucid_dem %>%
  select(CRT_Sum, Dem_Fake1, Dem_Fake2, Dem_Fake3, Dem_Fake4, Dem_Fake5, Rep_Fake1, Rep_Fake2, Rep_Fake3, Rep_Fake4, Rep_Fake5, Dem_Hyp1, Dem_Hyp2, Dem_Hyp3, Dem_Hyp4, Dem_Hyp5, Rep_Hyp1, Rep_Hyp2, Rep_Hyp3, Rep_Hyp4, Rep_Hyp5, Dem_Main1, Dem_Main2, Dem_Main3, Dem_Main4, Dem_Main5, Rep_Main1, Rep_Main2, Rep_Main3, Rep_Main4, Rep_Main5) %>% 
  corr.test(adjust = "none", minlength = 30) %>% 
  print(short = FALSE, digits = 5)
corr_share_lucid_dem <- corr_share_lucid_dem %>%
  rownames_to_column(var = "row_name")
corr_share_lucid_dem <- corr_share_lucid_dem %>%
  add_column(study = "Lucid_Democrat_Sharing")

corr_share_lucid_rep <- data_share_lucid_rep %>%
  select(CRT_Sum, Dem_Fake1, Dem_Fake2, Dem_Fake3, Dem_Fake4, Dem_Fake5, Rep_Fake1, Rep_Fake2, Rep_Fake3, Rep_Fake4, Rep_Fake5, Dem_Hyp1, Dem_Hyp2, Dem_Hyp3, Dem_Hyp4, Dem_Hyp5, Rep_Hyp1, Rep_Hyp2, Rep_Hyp3, Rep_Hyp4, Rep_Hyp5, Dem_Main1, Dem_Main2, Dem_Main3, Dem_Main4, Dem_Main5, Rep_Main1, Rep_Main2, Rep_Main3, Rep_Main4, Rep_Main5) %>% 
  corr.test(adjust = "none", minlength = 30) %>% 
  print(short = FALSE, digits = 5)
corr_share_lucid_rep <- corr_share_lucid_rep %>%
  rownames_to_column(var = "row_name")
corr_share_lucid_rep <- corr_share_lucid_rep %>%
  add_column(study = "Lucid_Republican_Sharing")

corr_individual <- bind_rows(corr_acc_mturk_dem, corr_acc_mturk_rep, corr_acc_lucid_dem, corr_acc_lucid_rep, corr_share_mturk_dem, corr_share_mturk_rep, corr_share_lucid_dem, corr_share_lucid_rep)

corr_individual <- corr_individual %>% 
  filter(grepl("CRT", row_name))

write.table(corr_individual,"corr_individual.csv", sep = ",")

#----------------------------
# Factor analysis

data_factor <- data %>% 
  filter(Study == 2) %>% 
  select(c(CRT_1_c, CRT_2_c, CRT_3_c, CRT_4_c, CRT_5_c, CRT_6_c, CRT_7_c, BNT_1_C, BNT_2_C, BNT_3_C, BNT_4_C))

# Figure S1
scree(data_factor, pc = FALSE, factors = TRUE, hline = "1", main = "")

# Table S17
fit <- data_factor %>% fa(nfactors = 2, rotate = "varimax")
fit
