########################################################
# Preprocess.R
########################################################

# 28 March 2021

# This R script loads the data file data_raw.csv and and outputs the data file data_preprocessed.csv which is used by the R script analysis.R

# Some columns were removed before data were uploaded to Open Science Framework to preserve participant anonymity:
# IPAddress
# WorkerID - which is the MTurk ID code
# LocationLatitude
# LocationLongitude
# Zipcode
# Comments
# confirmCode
# rid - which is the Lucid ID code
# Zip_Lucid

library(tidyverse)

# --------------------------------------------------------------------------
# Import data
# setwd("~/Desktop/misinformation")
data_raw <- read_csv("data_raw.csv", guess_max = 2000)

data <- subset(data_raw, select = c(SubjectNumber, Study, Progress, Duration, Facebook, Twitter, DemFake6_1, DemFake6_2, DemFake6_3, DemFake6_4, DemFake3_1, DemFake3_2, DemFake3_3, DemFake3_4, DemFake18_1, DemFake18_2, DemFake18_3, DemFake18_4, DemFake19_1, DemFake19_2, DemFake19_3, DemFake19_4, DemFake13_1, DemFake13_2, DemFake13_3, DemFake13_4, DemHyp8_1, DemHyp8_2, DemHyp8_3, DemHyp8_4, DemHyp20_1, DemHyp20_2, DemHyp20_3, DemHyp20_4, DemHyp13_1, DemHyp13_2, DemHyp13_3, DemHyp13_4, DemHyp6_1, DemHyp6_2, DemHyp6_3, DemHyp6_4, DemHyp14_1, DemHyp14_2, DemHyp14_3, DemHyp14_4, DemMain9_1, DemMain9_2, DemMain9_3, DemMain9_4, DemMain10_1, DemMain10_2, DemMain10_3, DemMain10_4, DemMain2_1, DemMain2_2, DemMain2_3, DemMain2_4, DemMain12_1, DemMain12_2, DemMain12_3, DemMain12_4, DemMain15_1, DemMain15_2, DemMain15_3, DemMain15_4, RepFake18_1, RepFake18_2, RepFake18_3, RepFake18_4, RepFake13_1, RepFake13_2, RepFake13_3, RepFake13_4, RepFake6_1, RepFake6_2, RepFake6_3, RepFake6_4, RepFake16_1, RepFake16_2, RepFake16_3, RepFake16_4, RepFake7_1, RepFake7_2, RepFake7_3, RepFake7_4, RepHyp4_1, RepHyp4_2, RepHyp4_3, RepHyp4_4, RepHyp20_1, RepHyp20_2, RepHyp20_3, RepHyp20_4, RepHyp13_1, RepHyp13_2, RepHyp13_3, RepHyp13_4, RepHyp1_1, RepHyp1_2, RepHyp1_3, RepHyp1_4, RepHyp10_1, RepHyp10_2, RepHyp10_3, RepHyp10_4, RepMain17_1, RepMain17_2, RepMain17_3, RepMain17_4, RepMain20_1, RepMain20_2, RepMain20_3, RepMain20_4, RepMain7_1, RepMain7_2, RepMain7_3, RepMain7_4, RepMain18_1, RepMain18_2, RepMain18_3, RepMain18_4, RepMain15_1, RepMain15_2, RepMain15_3, RepMain15_4, CRT1_1, CRT1_2, CRT1_3, CRT3_1, CRT3_2, CRT3_3, CRT3_4, CRT_chk, BNT_1, BNT_2, BNT_3, BNT_4, Age, Sex, Education, Education_Lucid, English, Party, DemRep_C, Social_Conserv, Economic_Conserv, POTUS2016, ClintonTrump, SocialCircle_2, Congress2018, Congress2018_v2, IdentCentral_1, IdentCentral_2, Media1, Media2, Media3_1, Media3_2, Media3_3, Media3_4, Media_Freq, Media_Share, AccImp, god, NFC1, NFC2, NFC3, NFC4, NFC5, NFC6, NFC7, NFC8, NFC9, NFC10, NFC11, NFC12, NFC13, NFC14, Random, Google, v))

data <- data %>% 
  rename(Education_MTurk = Education)

# Rename headlines for clearer numerical format.
data <- data %>% 
  rename(Dem_Fake1_1 = DemFake6_1,
         Dem_Fake1_2 = DemFake6_2,
         Dem_Fake1_3 = DemFake6_3,
         Dem_Fake1_4 = DemFake6_4,
         Dem_Fake2_1 = DemFake3_1,
         Dem_Fake2_2 = DemFake3_2,
         Dem_Fake2_3 = DemFake3_3,
         Dem_Fake2_4 = DemFake3_4,
         Dem_Fake3_1 = DemFake18_1,
         Dem_Fake3_2 = DemFake18_2,
         Dem_Fake3_3 = DemFake18_3,
         Dem_Fake3_4 = DemFake18_4,
         Dem_Fake4_1 = DemFake19_1,
         Dem_Fake4_2 = DemFake19_2,
         Dem_Fake4_3 = DemFake19_3,
         Dem_Fake4_4 = DemFake19_4,
         Dem_Fake5_1 = DemFake13_1,
         Dem_Fake5_2 = DemFake13_2,
         Dem_Fake5_3 = DemFake13_3,
         Dem_Fake5_4 = DemFake13_4,
         Rep_Fake1_1 = RepFake18_1,
         Rep_Fake1_2 = RepFake18_2,
         Rep_Fake1_3 = RepFake18_3,
         Rep_Fake1_4 = RepFake18_4,
         Rep_Fake2_1 = RepFake13_1, 
         Rep_Fake2_2 = RepFake13_2, 
         Rep_Fake2_3 = RepFake13_3, 
         Rep_Fake2_4 = RepFake13_4, 
         Rep_Fake3_1 = RepFake6_1, 
         Rep_Fake3_2 = RepFake6_2,
         Rep_Fake3_3 = RepFake6_3,
         Rep_Fake3_4 = RepFake6_4,
         Rep_Fake4_1 = RepFake16_1, 
         Rep_Fake4_2 = RepFake16_2, 
         Rep_Fake4_3 = RepFake16_3, 
         Rep_Fake4_4 = RepFake16_4, 
         Rep_Fake5_1 = RepFake7_1, 
         Rep_Fake5_2 = RepFake7_2, 
         Rep_Fake5_3 = RepFake7_3, 
         Rep_Fake5_4 = RepFake7_4, 
         Dem_Hyp1_1 = DemHyp8_1, 
         Dem_Hyp1_2 = DemHyp8_2, 
         Dem_Hyp1_3 = DemHyp8_3, 
         Dem_Hyp1_4 = DemHyp8_4, 
         Dem_Hyp2_1 = DemHyp20_1,
         Dem_Hyp2_2 = DemHyp20_2,
         Dem_Hyp2_3 = DemHyp20_3,
         Dem_Hyp2_4 = DemHyp20_4,
         Dem_Hyp3_1 = DemHyp13_1, 
         Dem_Hyp3_2 = DemHyp13_2, 
         Dem_Hyp3_3 = DemHyp13_3, 
         Dem_Hyp3_4 = DemHyp13_4, 
         Dem_Hyp4_1 = DemHyp6_1, 
         Dem_Hyp4_2 = DemHyp6_2, 
         Dem_Hyp4_3 = DemHyp6_3, 
         Dem_Hyp4_4 = DemHyp6_4, 
         Dem_Hyp5_1 = DemHyp14_1, 
         Dem_Hyp5_2 = DemHyp14_2, 
         Dem_Hyp5_3 = DemHyp14_3, 
         Dem_Hyp5_4 = DemHyp14_4, 
         Rep_Hyp1_1 = RepHyp4_1, 
         Rep_Hyp1_2 = RepHyp4_2, 
         Rep_Hyp1_3 = RepHyp4_3, 
         Rep_Hyp1_4 = RepHyp4_4, 
         Rep_Hyp2_1 = RepHyp20_1, 
         Rep_Hyp2_2 = RepHyp20_2, 
         Rep_Hyp2_3 = RepHyp20_3, 
         Rep_Hyp2_4 = RepHyp20_4, 
         Rep_Hyp3_1 = RepHyp13_1, 
         Rep_Hyp3_2 = RepHyp13_2, 
         Rep_Hyp3_3 = RepHyp13_3, 
         Rep_Hyp3_4 = RepHyp13_4, 
         Rep_Hyp4_1 = RepHyp1_1,
         Rep_Hyp4_2 = RepHyp1_2,
         Rep_Hyp4_3 = RepHyp1_3,
         Rep_Hyp4_4 = RepHyp1_4,
         Rep_Hyp5_1 = RepHyp10_1, 
         Rep_Hyp5_2 = RepHyp10_2, 
         Rep_Hyp5_3 = RepHyp10_3, 
         Rep_Hyp5_4 = RepHyp10_4, 
         Dem_Main1_1 = DemMain9_1, 
         Dem_Main1_2 = DemMain9_2,
         Dem_Main1_3 = DemMain9_3,
         Dem_Main1_4 = DemMain9_4,
         Dem_Main2_1 = DemMain10_1, 
         Dem_Main2_2 = DemMain10_2, 
         Dem_Main2_3 = DemMain10_3, 
         Dem_Main2_4 = DemMain10_4, 
         Dem_Main3_1 = DemMain2_1, 
         Dem_Main3_2 = DemMain2_2, 
         Dem_Main3_3 = DemMain2_3, 
         Dem_Main3_4 = DemMain2_4, 
         Dem_Main4_1 = DemMain12_1, 
         Dem_Main4_2 = DemMain12_2, 
         Dem_Main4_3 = DemMain12_3, 
         Dem_Main4_4 = DemMain12_4,
         Dem_Main5_1 = DemMain15_1, 
         Dem_Main5_2 = DemMain15_2, 
         Dem_Main5_3 = DemMain15_3, 
         Dem_Main5_4 = DemMain15_4, 
         Rep_Main1_1 = RepMain17_1, 
         Rep_Main1_2 = RepMain17_2, 
         Rep_Main1_3 = RepMain17_3, 
         Rep_Main1_4 = RepMain17_4, 
         Rep_Main2_1 = RepMain20_1, 
         Rep_Main2_2 = RepMain20_2, 
         Rep_Main2_3 = RepMain20_3, 
         Rep_Main2_4 = RepMain20_4, 
         Rep_Main3_1 = RepMain7_1, 
         Rep_Main3_2 = RepMain7_2, 
         Rep_Main3_3 = RepMain7_3, 
         Rep_Main3_4 = RepMain7_4, 
         Rep_Main4_1 = RepMain18_1, 
         Rep_Main4_2 = RepMain18_2, 
         Rep_Main4_3 = RepMain18_3, 
         Rep_Main4_4 = RepMain18_4, 
         Rep_Main5_1 = RepMain15_1, 
         Rep_Main5_2 = RepMain15_2, 
         Rep_Main5_3 = RepMain15_3, 
         Rep_Main5_4 = RepMain15_4)

# Data exclusions included in preregistration
data <- data %>% 
  filter(Progress == 100) ### Remove participants who didn't complete the study.
data <- data %>% 
  filter(!is.na(Random)) ### Remove participants who didn't complete the study.
data <- data %>% 
  filter(!is.na(Google)) ### Remove participants who didn't complete the study.

# Data exclusions not included in preregistration
data <- data %>% 
  filter(!is.na(DemRep_C)) ### Removes 23 participants who didn't complete the continuous measure of political beliefs (it must be a Qualtrics coding error that this question wasn't compulsory because all other questions in the study are compulsory).

rm(data_raw)

# -----------------------------------
# CRT wrangling

CRT_Qs <- data %>%
  dplyr::select(CRT1_1, CRT1_2, CRT1_3, CRT3_1, CRT3_2, CRT3_3, CRT3_4) %>%
  map_df(.x = ., .f = tolower) %>%
  map_df(.x = ., .f = trimws) %>%
  mutate(CRT_1_c = case_when(CRT1_1 == 4 ~ 1, TRUE ~ 0),
         CRT_2_c = case_when(CRT1_2 == 10 ~ 1, TRUE ~ 0),
         CRT_3_c = case_when(CRT1_3 == 39 ~ 1, TRUE ~ 0),
         CRT_4_c = case_when(CRT3_1 %in% c("2", "second", "2nd", "second place", "2nd place", "segundo", "1st runner up") ~ 1, TRUE ~ 0),
         CRT_5_c = case_when(CRT3_2 %in% c("8") ~ 1, TRUE ~ 0),
         CRT_6_c = case_when(CRT3_3 %in% c("emily", "emely", "emily's", "wmily", "emilys") ~ 1, TRUE ~ 0),
         CRT_7_c = case_when(CRT3_4 %in% c("0", "none", "none - it's an empty hole", "zero", "none, if it's a hole, it's empty by definition", "none, it's a hole", "0 (it's a hole)", "o", "no dirt", "nonoe", "none its a hole", "there is no dirt in a hole", "n/a", "na") ~ 1, TRUE ~ 0)
  ) %>%
  dplyr::select(-c(CRT1_1:CRT3_4)) %>%
  mutate(CRT_Sum = rowSums(.))

data <- cbind(data, CRT_Qs)
rm(CRT_Qs)

#-----------------------------------
# BNT wrangling

data <- data %>% 
  mutate(BNT_1_C = ifelse(BNT_1 == 30, 1, 0),
                        BNT_2_C = ifelse(BNT_2 == 25, 1, 0),
                        BNT_3_C = ifelse(BNT_3 == 20, 1, 0),
                        BNT_4_C = ifelse(BNT_4 == 50, 1, 0))

data_Study1 <- data %>% 
  filter(Study == 1)
data_Study2 <- data %>% 
  filter(Study == 2)

data_Study2$BNT_1_C[is.na(data_Study2$BNT_1_C)] <- 0
data_Study2$BNT_2_C[is.na(data_Study2$BNT_2_C)] <- 0
data_Study2$BNT_3_C[is.na(data_Study2$BNT_3_C)] <- 0
data_Study2$BNT_4_C[is.na(data_Study2$BNT_4_C)] <- 0

data <- bind_rows(data_Study1, data_Study2) %>%
  arrange(SubjectNumber)

data <- data %>% 
  mutate(BNT_Sum = (BNT_1_C + BNT_2_C + BNT_3_C + BNT_4_C))

rm("data_Study1", "data_Study2")

#------------------------------
# CRT + BNT wrangling

data <- data %>% 
  mutate(CRT_BNT_Sum = (CRT_Sum + BNT_Sum))

#-----------------------------
# NFC wrangling

data <- data %>% 
  mutate(NFC_Sum = (NFC1 + NFC2 + NFC3 + NFC4 + NFC5 + NFC6 + NFC7 + NFC8 + NFC9 + NFC10 + NFC11 + NFC12 + NFC13 + NFC14))

#----------------------------
# Code participants as being in accuracy judgement vs sharing condition

data <- data %>%
  mutate(Condition = ifelse(v == 1, 1,
                            ifelse(v == 2, 1,
                                   ifelse(v == 3, 2,
                                          ifelse(v == 4, 2, NA)))))

#-----------------------------
# Code participants as Democrat vs Republican using Likert scale

data <- data %>%
  mutate(DemRep = ifelse(DemRep_C < 4, 1, 2))

#----------------------------
# Code participants by whether or not they are partisan (i.e. use extreme end of scale)

data <- data %>%
  mutate(Partisan = ifelse(DemRep_C == 1 | DemRep_C == 6, 1,
                           ifelse(DemRep_C == 2 | DemRep_C == 3 | DemRep_C == 4 | DemRep_C == 5, 2, NA)))

#---------------------------
# Calculate responses to individual items

data <- data %>% 
  rowwise() %>%
  mutate(Dem_Fake1 = sum(Dem_Fake1_1, Dem_Fake1_2, Dem_Fake1_3, Dem_Fake1_4, na.rm = TRUE),
         Dem_Fake2 = sum(Dem_Fake2_1, Dem_Fake2_2, Dem_Fake2_3, Dem_Fake2_4, na.rm = TRUE),
         Dem_Fake3 = sum(Dem_Fake3_1, Dem_Fake3_2, Dem_Fake3_3, Dem_Fake3_4, na.rm = TRUE),
         Dem_Fake4 = sum(Dem_Fake4_1, Dem_Fake4_2, Dem_Fake4_3, Dem_Fake4_4, na.rm = TRUE),
         Dem_Fake5 = sum(Dem_Fake5_1, Dem_Fake5_2, Dem_Fake5_3, Dem_Fake5_4, na.rm = TRUE),
         Dem_Hyp1 = sum(Dem_Hyp1_1, Dem_Hyp1_2, Dem_Hyp1_3, Dem_Hyp1_4, na.rm = TRUE),
         Dem_Hyp2 = sum(Dem_Hyp2_1, Dem_Hyp2_2, Dem_Hyp2_3, Dem_Hyp2_4, na.rm = TRUE),
         Dem_Hyp3 = sum(Dem_Hyp3_1, Dem_Hyp3_2, Dem_Hyp3_3, Dem_Hyp3_4, na.rm = TRUE),
         Dem_Hyp4 = sum(Dem_Hyp4_1, Dem_Hyp4_2, Dem_Hyp4_3, Dem_Hyp4_4, na.rm = TRUE),
         Dem_Hyp5 = sum(Dem_Hyp5_1, Dem_Hyp5_2, Dem_Hyp5_3, Dem_Hyp5_4, na.rm = TRUE),
         Dem_Main1 = sum(Dem_Main1_1, Dem_Main1_2, Dem_Main1_3, Dem_Main1_4, na.rm = TRUE),
         Dem_Main2 = sum(Dem_Main2_1, Dem_Main2_2, Dem_Main2_3, Dem_Main2_4, na.rm = TRUE),
         Dem_Main3 = sum(Dem_Main3_1, Dem_Main3_2, Dem_Main3_3, Dem_Main3_4, na.rm = TRUE),
         Dem_Main4 = sum(Dem_Main4_1, Dem_Main4_2, Dem_Main4_3, Dem_Main4_4, na.rm = TRUE),
         Dem_Main5 = sum(Dem_Main5_1, Dem_Main5_2, Dem_Main5_3, Dem_Main5_4, na.rm = TRUE),
         Rep_Fake1 = sum(Rep_Fake1_1, Rep_Fake1_2, Rep_Fake1_3, Rep_Fake1_4, na.rm = TRUE),
         Rep_Fake2 = sum(Rep_Fake2_1, Rep_Fake2_2, Rep_Fake2_3, Rep_Fake2_4, na.rm = TRUE),
         Rep_Fake3 = sum(Rep_Fake3_1, Rep_Fake3_2, Rep_Fake3_3, Rep_Fake3_4, na.rm = TRUE),
         Rep_Fake4 = sum(Rep_Fake4_1, Rep_Fake4_2, Rep_Fake4_3, Rep_Fake4_4, na.rm = TRUE),
         Rep_Fake5 = sum(Rep_Fake5_1, Rep_Fake5_2, Rep_Fake5_3, Rep_Fake5_4, na.rm = TRUE),
         Rep_Hyp1 = sum(Rep_Hyp1_1, Rep_Hyp1_2, Rep_Hyp1_3, Rep_Hyp1_4, na.rm = TRUE),
         Rep_Hyp2 = sum(Rep_Hyp2_1, Rep_Hyp2_2, Rep_Hyp2_3, Rep_Hyp2_4, na.rm = TRUE),
         Rep_Hyp3 = sum(Rep_Hyp3_1, Rep_Hyp3_2, Rep_Hyp3_3, Rep_Hyp3_4, na.rm = TRUE),
         Rep_Hyp4 = sum(Rep_Hyp4_1, Rep_Hyp4_2, Rep_Hyp4_3, Rep_Hyp4_4, na.rm = TRUE),
         Rep_Hyp5 = sum(Rep_Hyp5_1, Rep_Hyp5_2, Rep_Hyp5_3, Rep_Hyp5_4, na.rm = TRUE),
         Rep_Main1 = sum(Rep_Main1_1, Rep_Main1_2, Rep_Main1_3, Rep_Main1_4, na.rm = TRUE),
         Rep_Main2 = sum(Rep_Main2_1, Rep_Main2_2, Rep_Main2_3, Rep_Main2_4, na.rm = TRUE),
         Rep_Main3 = sum(Rep_Main3_1, Rep_Main3_2, Rep_Main3_3, Rep_Main3_4, na.rm = TRUE),
         Rep_Main4 = sum(Rep_Main4_1, Rep_Main4_2, Rep_Main4_3, Rep_Main4_4, na.rm = TRUE),
         Rep_Main5 = sum(Rep_Main5_1, Rep_Main5_2, Rep_Main5_3, Rep_Main5_4, na.rm = TRUE)
  )

# Remove unneeded columns
data <- select(data, 
               -c(Dem_Fake1_1, Dem_Fake1_2,
                  Dem_Fake2_1, Dem_Fake2_2, 
                  Dem_Fake3_1, Dem_Fake3_2,
                  Dem_Fake4_1, Dem_Fake4_2,
                  Dem_Fake5_1, Dem_Fake5_2, 
                  Dem_Hyp1_1, Dem_Hyp1_2, 
                  Dem_Hyp2_1, Dem_Hyp2_2, 
                  Dem_Hyp3_1, Dem_Hyp3_2, 
                  Dem_Hyp4_1, Dem_Hyp4_2, 
                  Dem_Hyp5_1, Dem_Hyp5_2, 
                  Dem_Main1_1, Dem_Main1_2, 
                  Dem_Main2_1, Dem_Main2_2, 
                  Dem_Main3_1, Dem_Main3_2, 
                  Dem_Main4_1, Dem_Main4_2, 
                  Dem_Main5_1, Dem_Main5_2, 
                  Rep_Fake1_1, Rep_Fake1_2, 
                  Rep_Fake2_1, Rep_Fake2_2, 
                  Rep_Fake3_1, Rep_Fake3_2, 
                  Rep_Fake4_1, Rep_Fake4_2, 
                  Rep_Fake5_1, Rep_Fake5_2, 
                  Rep_Hyp1_1, Rep_Hyp1_2, 
                  Rep_Hyp2_1, Rep_Hyp2_2, 
                  Rep_Hyp3_1, Rep_Hyp3_2, 
                  Rep_Hyp4_1, Rep_Hyp4_2, 
                  Rep_Hyp5_1, Rep_Hyp5_2, 
                  Rep_Main1_1, Rep_Main1_2, 
                  Rep_Main2_1, Rep_Main2_2, 
                  Rep_Main3_1, Rep_Main3_2, 
                  Rep_Main4_1, Rep_Main4_2, 
                  Rep_Main5_1, Rep_Main5_2, 
                  Dem_Fake1_3, Dem_Fake1_4, 
                  Dem_Fake2_3, Dem_Fake2_4, 
                  Dem_Fake3_3, Dem_Fake3_4, 
                  Dem_Fake4_3, Dem_Fake4_4, 
                  Dem_Fake5_3, Dem_Fake5_4, 
                  Dem_Hyp1_3, Dem_Hyp1_4, 
                  Dem_Hyp2_3, Dem_Hyp2_4, 
                  Dem_Hyp3_3, Dem_Hyp3_4, 
                  Dem_Hyp4_3, Dem_Hyp4_4, 
                  Dem_Hyp5_3, Dem_Hyp5_4, 
                  Dem_Main1_3, Dem_Main1_4, 
                  Dem_Main2_3, Dem_Main2_4, 
                  Dem_Main3_3, Dem_Main3_4, 
                  Dem_Main4_3, Dem_Main4_4, 
                  Dem_Main5_3, Dem_Main5_4, 
                  Rep_Fake1_3, Rep_Fake1_4, 
                  Rep_Fake2_3, Rep_Fake2_4, 
                  Rep_Fake3_3, Rep_Fake3_4, 
                  Rep_Fake4_3, Rep_Fake4_4, 
                  Rep_Fake5_3, Rep_Fake5_4, 
                  Rep_Hyp1_3, Rep_Hyp1_4, 
                  Rep_Hyp2_3, Rep_Hyp2_4, 
                  Rep_Hyp3_3, Rep_Hyp3_4, 
                  Rep_Hyp4_3, Rep_Hyp4_4, 
                  Rep_Hyp5_3, Rep_Hyp5_4, 
                  Rep_Main1_3, Rep_Main1_4, 
                  Rep_Main2_3, Rep_Main2_4, 
                  Rep_Main3_3, Rep_Main3_4, 
                  Rep_Main4_3, Rep_Main4_4, 
                  Rep_Main5_3, Rep_Main5_4
               )
)

#---------------------------

data_backup <- data

data <- data %>%
  filter(Condition == 1 | (Condition == 2 & Media_Share == 1))

#---------------------------
# Raw scores by news category

data <- data %>%
  mutate(Fake = mean(c(Dem_Fake1, Dem_Fake2, Dem_Fake3, Dem_Fake4, Dem_Fake5, Rep_Fake1, Rep_Fake2, Rep_Fake3, Rep_Fake4, Rep_Fake5)),
         Hyp = mean(c(Dem_Hyp1, Dem_Hyp2, Dem_Hyp3, Dem_Hyp4, Dem_Hyp5, Rep_Hyp1, Rep_Hyp2, Rep_Hyp3, Rep_Hyp4, Rep_Hyp5)),
         Main = mean(c(Dem_Main1, Dem_Main2, Dem_Main3, Dem_Main4, Dem_Main5, Rep_Main1, Rep_Main2, Rep_Main3, Rep_Main4, Rep_Main5))
  )

# Raw scores by news category and political support
data <- data %>%
  rowwise() %>%
  mutate(Fake_Dem = mean(c(Dem_Fake1, Dem_Fake2, Dem_Fake3, Dem_Fake4, Dem_Fake5)),
         Hyp_Dem = mean(c(Dem_Hyp1, Dem_Hyp2, Dem_Hyp3, Dem_Hyp4, Dem_Hyp5)),
         Main_Dem = mean(c(Dem_Main1, Dem_Main2, Dem_Main3, Dem_Main4, Dem_Main5)),
         Fake_Rep = mean(c(Rep_Fake1, Rep_Fake2, Rep_Fake3, Rep_Fake4, Rep_Fake5)),
         Hyp_Rep = mean(c(Rep_Hyp1, Rep_Hyp2, Rep_Hyp3, Rep_Hyp4, Rep_Hyp5)),
         Main_Rep = mean(c(Rep_Main1, Rep_Main2, Rep_Main3, Rep_Main4, Rep_Main5))
  )

# Z-scores by news category and political support
data <- data %>%
  group_by(Study, Condition) %>%
  mutate(ZFake_Dem = (Fake_Dem - mean(Fake_Dem))/sd(Fake_Dem),
         ZHyp_Dem = (Hyp_Dem - mean(Hyp_Dem))/sd(Hyp_Dem),
         ZMain_Dem = (Main_Dem - mean(Main_Dem))/sd(Main_Dem),
         ZFake_Rep = (Fake_Rep - mean(Fake_Rep))/sd(Fake_Rep),
         ZHyp_Rep = (Hyp_Rep - mean(Hyp_Rep))/sd(Hyp_Rep),
         ZMain_Rep = (Main_Rep - mean(Main_Rep))/sd(Main_Rep)
  )

# Z-scores for discernment by news category and political support
data <- data %>% 
  mutate(ZDis_Main_Minus_Fake_Dem = ZMain_Dem - ZFake_Dem,
         ZDis_Main_Minus_Hyp_Dem = ZMain_Dem - ZHyp_Dem,
         ZDis_Hyp_Minus_Fake_Dem = ZHyp_Dem - ZFake_Dem,
         ZDis_Main_Minus_Fake_Rep = ZMain_Rep - ZFake_Rep,
         ZDis_Main_Minus_Hyp_Rep = ZMain_Rep - ZHyp_Rep,
         ZDis_Hyp_Minus_Fake_Rep = ZHyp_Rep - ZFake_Rep)

# Raw scores by news category and political concordance
data_Dem <- data %>%
  filter(DemRep == 1) %>% 
  mutate(Fake_PC = Fake_Dem, 
         Hyp_PC = Hyp_Dem,
         Main_PC = Main_Dem,
         Fake_nPC = Fake_Rep,
         Hyp_nPC = Hyp_Rep,
         Main_nPC = Main_Rep)

data_Rep <- data %>% 
  filter(DemRep == 2) %>% 
  mutate(Fake_nPC = Fake_Dem,
         Hyp_nPC = Hyp_Dem,
         Main_nPC = Main_Dem,
         Fake_PC = Fake_Rep,
         Hyp_PC = Hyp_Rep,
         Main_PC = Main_Rep)

data <- bind_rows(data_Dem, data_Rep)

rm(data_Rep, data_Dem)

# Z-scores by news category and political concordance
data <- data %>% 
  group_by(Study, Condition) %>%
  mutate(ZFake_PC = (Fake_PC - mean(Fake_PC))/sd(Fake_PC),
         ZHyp_PC = (Hyp_PC - mean(Hyp_PC))/sd(Hyp_PC),
         ZMain_PC = (Main_PC - mean(Main_PC))/sd(Main_PC),
         ZFake_nPC = (Fake_nPC - mean(Fake_nPC))/sd(Fake_nPC),
         ZHyp_nPC = (Hyp_nPC - mean(Hyp_nPC))/sd(Hyp_nPC),
         ZMain_nPC = (Main_nPC - mean(Main_nPC))/sd(Main_nPC)
         )

# Z-scores for discernment by news category and political concordance
data <- data %>% 
  mutate(ZDis_Main_PC_Minus_Fake_PC = ZMain_PC - ZFake_PC,
         ZDis_Main_PC_Minus_Hyp_PC = ZMain_PC - ZHyp_PC,
         ZDis_Hyp_PC_Minus_Fake_PC = ZHyp_PC - ZFake_PC,
         ZDis_Main_nPC_Minus_Fake_nPC = ZMain_nPC - ZFake_nPC,
         ZDis_Main_nPC_Minus_Hyp_nPC = ZMain_nPC - ZHyp_nPC,
         ZDis_Hyp_nPC_Minus_Fake_nPC = ZHyp_nPC - ZFake_nPC
         )

data_join <- full_join(data_backup, data)

data_join <- data_join %>% 
  arrange(SubjectNumber)

write_csv(data_join, file = "data_preprocessed.csv")